// SPDX-License-Identifier: Apache-2.0
// Copyright Authors of Popeye

package client

const (
	// NA Not available
	NA = "n/a"

	// NamespaceAll designates the fictional all namespace.
	NamespaceAll = "all"

	// AllNamespaces designates all namespaces.
	AllNamespaces = ""

	// ClusterScope designates a resource is not namespaced.
	ClusterScope = "-"

	// NotNamespaced designates a non resource namespace.
	NotNamespaced = "*"

	// BlankNamespace tracks an unspecified namespace.
	BlankNamespace = ""

	// DefaultNamespace tracks the default namespace.
	DefaultNamespace = "default"
)
